# Data Models

## Roadway

### Tables

::: network_wrangler.models.roadway.tables

### Types

::: network_wrangler.models.roadway.types

## Transit

::: network_wrangler.transit.feed.feed

### Pure GTFS Tables

::: network_wrangler.models.gtfs

## Project Cards

### Projects

::: network_wrangler.models.projects.roadway_changes.RoadwayDeletion
::: network_wrangler.models.projects.roadway_changes.RoadPropertyChange

### Roadway Selections

::: network_wrangler.models.projects.roadway_selection

### Transit Selections

::: network_wrangler.models.projects.transit_selection
